pub struct Verified { /* private fields */ }Expand description
Webhook payload that passed signature validation and required entity/event checks.
Implementations
Sourceimpl Verified
impl Verified
Sourcepub fn event_type(&self) -> EventType
pub fn event_type(&self) -> EventType
Returns the normalized Gingr event type for a verified webhook.
Sourcepub fn entity_id(&self) -> &EntityId
pub fn entity_id(&self) -> &EntityId
Returns the provider entity identifier from the verified webhook.
Sourcepub fn entity_type(&self) -> EntityType
pub fn entity_type(&self) -> EntityType
Returns the normalized Gingr entity type for a verified webhook.